@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious';
 
 use Data::Dumper;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use File::Basename 'dirname';
 use File::Spec;
@@ -93,8 +93,12 @@ sub startup {
   $routes->get('/')->to('front#index');
   $routes->get('/front/*name')->to('front#page');
   $routes->get('/dist/*name')->to('dist#show');
-  $routes->get('/author/*author')->to('author#show');
+  $routes->post('/dist')->to('dist#query');
+  $routes->get('/dists' => sub { shift->render });
 
+  $routes->get('/author/*author')->to('author#show');
+  $routes->post('/author')->to('author#query');
+  $routes->get('/authors' => sub { shift->render });
   $routes->get('/about' => sub { shift->render });
 
 
